
local moduleName = "ToT"
local L = AceLibrary('AceLocale-2.2'):new('SimpleUnitFrames_ToT')
local ToT = SimpleUnitFrames:NewModule(moduleName)

L:RegisterTranslations('enUS', function() return {

	["ToT Frame"] = true,
	["Description"] = "Options for the ToT frame",
	["Middle Health Text"] = true,
	["Right Health Text"] = true,
	["Middle Mana Text"] = true,
	["Right Mana Text"] = true,
	["Middle Health Text Description"] = "Set middle health text to one of the formats",
	["Right Health Text Description"] = "Set right health text to one of the formats",
	["Middle Mana Text Description"] = "Set middle mana text to one of the formats",
	["Right Mana Text Description"] = "Set right health text to one of the formats",
	
} end)

L:RegisterTranslations('krKR', function() return {

	["ToT Frame"] = "대상의 대상 프레임",
	["Description"] = "대상의 대상 프레임에 대한 설정",
	["Middle Health Text"] = "중간 생명력 글자",
	["Right Health Text"] = "오른쪽 생명력 글자",
	["Middle Mana Text"] = "중간 마나 글자",
	["Right Mana Text"] = "오른쪽 마나 글자",
	["Middle Health Text Description"] = "중간 생명력 글자 표시 방법 선택",
	["Right Health Text Description"] = "오른쪽 생명력 글자 표시 방법 선택",
	["Middle Mana Text Description"] = "중간 마나 글자 표시 방법 선택",
	["Right Mana Text Description"] = "오른쪽 마나 글자 표시 방법 선택",
	
} end)

function ToT:GetConsoleOptions()
	local OPTION_ORDER = 100
	return {
		type = 'group',
		name = L['ToT Frame'],
		desc = L['Description'],
		args = {	
			mhp = {
				order = OPTION_ORDER + 1,
				type = 'text',
				name = L['Middle Health Text'],
				desc = L['Middle Health Text Description'],
				get = function() return self.db.profile.mhp end,
				set = function(v) 
								self.db.profile.mhp = v
								self:TargetofTarget_Update()
							end,
				validate = self.core.formatList,
			},
			rhp = {
				order = OPTION_ORDER + 2,
				type = 'text',
				name = L['Right Health Text'],
				desc = L['Right Health Text Description'],
				get = function() return self.db.profile.rhp end,
				set = function(v) 
								self.db.profile.rhp = v
								self:TargetofTarget_Update()
							end,
				validate = self.core.formatList,
			},
			mmp = {
				order = OPTION_ORDER + 3,
				type = 'text',
				name = L['Middle Mana Text'],
				desc = L['Middle Mana Text Description'],
				get = function() return self.db.profile.mmp end,
				set = function(v)
								self.db.profile.mmp = v
								self:TargetofTarget_Update()
							end,
				validate = self.core.formatList,
			},
			rmp = {
				order = OPTION_ORDER + 4,
				type = 'text',
				name = L['Right Mana Text'],
				desc = L['Right Mana Text Description'],
				get = function() return self.db.profile.rmp end,
				set = function(v)
								self.db.profile.rmp = v
								self:TargetofTarget_Update()
							end,
				validate = self.core.formatList,
			},
		}
	}

end

function ToT:OnInitialize()
	self.db = SimpleUnitFrames:AcquireDBNamespace(moduleName)

	SimpleUnitFrames:RegisterDefaults(moduleName, 'profile', {
		mhp = "none",
		rhp = "percenthp",
		mmp = "none",
		rmp = "percentmp",		
	} )
	
	local parentFrame = TargetofTargetFrame
	local frame = CreateFrame("Frame", nil, parentFrame)
	frame:SetFrameLevel(parentFrame:GetFrameLevel()+2)
	frame:SetPoint("TOP")

	local fontString
	
	-- Middle Health Text.
	fontString = 	frame:CreateFontString(nil, "OVERLAY", "GameFontHighlightSmall")
	fontString:SetPoint("TOPRIGHT", TargetofTargetHealthBar, "TOPRIGHT", 0, 2)
	self.mhpText = fontString

	-- Right Health Text
	fontString = 	frame:CreateFontString(nil, "OVERLAY", "GameFontHighlightSmall")
	fontString:SetPoint("TOPLEFT", TargetofTargetHealthBar, "TOPRIGHT", 32, 2)
	self.rhpText = fontString
	
	-- Middle Mana Text.
	fontString = frame:CreateFontString(nil, "OVERLAY", "GameFontHighlightSmall")
	fontString:SetPoint("TOPRIGHT", TargetofTargetManaBar, "TOPRIGHT", 0, 2)
	self.mmpText = fontString
	
	-- Right Mana Text.
	fontString = frame:CreateFontString(nil, "OVERLAY", "GameFontHighlightSmall")
	fontString:SetPoint("TOPLEFT", TargetofTargetManaBar, "TOPRIGHT", 32, 2)
	self.rmpText = fontString	

	hooksecurefunc("TargetofTarget_Update", function() self:TargetofTarget_Update() end )

end

function ToT:TargetofTarget_Update()
	if TargetofTargetFrame:IsShown() then
		self:UpdateHealth()
		self:UpdateMana()
	end
end


function ToT:UpdateHealth()
	local text
	text = self:GetValueText('targettarget', self.db.profile.mhp)
	self.mhpText:SetText(text)
	text = self:GetValueText('targettarget', self.db.profile.rhp)
	self.rhpText:SetText(text)
end

function ToT:UpdateMana()
	local text
	text = self:GetValueText('targettarget', self.db.profile.mmp)
	self.mmpText:SetText(text)
	text = self:GetValueText('targettarget', self.db.profile.rmp)
	self.rmpText:SetText(text)
end
